@@ -65,7 +65,7 @@ key_results = 'F4'
 #SCB_STARTERS_FMT = [(3, 'r'), ' ', (SCB_STARTERS_NW,'l'), ' ', (4,'r')]
 
 SCB_RESMEDAL_NW = metarace.SCB_LINELEN - 7
-SCB_RESMEDAL_FMT = [(6,'l'), ' ', (SCB_RESMEDAL_NW,'l')]
+SCB_RESMEDAL_FMT = [(6,u'l'), u' ', (SCB_RESMEDAL_NW,u'l')]
 
 class classification(object):
     def loadconfig(self):
@@ -102,19 +102,27 @@ class classification(object):
 
     def startlist_report(self):
         """Return a startlist report."""
+        ret = []
         sec = printing.section()
-        sec.heading = ' '.join([
-                      'Event', self.evno, ':',
-                  self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                  self.meet.edb.getvalue(self.event, eventdb.COL_INFO),
-                      '- Start List'])
+        sec.heading = u' '.join([
+                      u'Event', self.evno, u':', self.event[u'pref'],
+                         self.event[u'info'],
+                      u'- Start List'])
+        lapstring = strops.lapstring(self.event[u'laps'])
+        substr = u' '.join([lapstring, self.event[u'dist'],
+                             self.event[u'prog']]).strip()
+        if substr:
+            sec.subheading = substr
         sec.lines = []
         for r in self.riders:
             rno = r[COL_BIB]
+            if u't' in self.series: # Team no hack
+                rno = u' '  # force name
             rname = strops.resname(r[COL_FIRST], r[COL_LAST],
                                        r[COL_CLUB])
             sec.lines.append([None, rno, rname, None, None, None])
-        return sec
+        ret.append(sec)
+        return ret
 
     def get_startlist(self):
         """Return a list of bibs in the rider model."""
@@ -163,14 +171,20 @@ class classification(object):
 
         # start with the overall result
         sec = printing.section()
-        sec.heading = 'Event ' + self.evno + ': ' + ' '.join([
-                       self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                       self.meet.edb.getvalue(self.event, eventdb.COL_INFO)
-                              ]).strip()
+        sec.heading = u'Event ' + self.evno + u': ' + u' '.join([
+                          self.event[u'pref'], self.event[u'info'] ]).strip()
+        sec.lines = []
+        lapstring = strops.lapstring(self.event[u'laps'])
+        substr = u' '.join([lapstring, self.event[u'dist'],
+                             self.event[u'prog']]).strip()
+        if substr:
+            sec.subheading = substr
         prevmedal = ''
         sec.lines = []
         for r in self.riders:
             rno = r[COL_BIB]
+            if u't' in self.series: # Team no hack
+                rno = u' '  # force name
             rname = strops.resname(r[COL_FIRST], r[COL_LAST],
                                        r[COL_CLUB])
             rank = ''
@@ -203,33 +217,10 @@ class classification(object):
                 if r.onestart:	# go for result
                     ret.extend(r.result_report())
                 else:		# go for startlist
-                    ret.append(r.startlist_report())
+                    ret.extend(r.startlist_report())
                 r.destroy()
         return ret
 
-    def result_export(self, f):
-        """Export results to supplied file handle."""
-        cr = csv.writer(f)
-        header = ['Event ' + self.evno, '', ' '.join([
-                       self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                       self.meet.edb.getvalue(self.event, eventdb.COL_INFO)
-                              ]).strip(),
-                     '', '']
-        cr.writerow(header)
-
-        for r in self.riders:
-            rno = r[COL_BIB]
-            rname = strops.resname(r[COL_FIRST], r[COL_LAST],
-                                       r[COL_CLUB])
-            rank = ''
-            if r[COL_PLACE] != '':
-                rank = r[COL_PLACE]
-                if rank.isdigit():
-                    rank += '.'
-            medal = r[COL_MEDAL]
-            orow = ["'"+rank, rno, rname,'',"'"+medal]
-            cr.writerow(orow)
-
     def addrider(self, bib='', place=''):
         """Add specified rider to race model."""
         nr=[bib, '', '', '', '', '', '']
@@ -347,11 +338,9 @@ class classification(object):
 # TODO
         if self.winopen:
             self.meet.announce.clrall()
-
             self.meet.ann_title(' '.join([
-                  'Event', self.evno, ':',
-                  self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                  self.meet.edb.getvalue(self.event, eventdb.COL_INFO) ]))
+                  'Event', self.evno, ':', self.event[u'pref'],
+                   self.event[u'info']]))
             self.meet.announce.linefill(1, '_')
             lmedal = ''
             l = 4
@@ -396,10 +385,8 @@ class classification(object):
                 break
         self.meet.scbwin = None
         self.meet.scbwin = scbwin.scbintsprint(self.meet.scb,
-                                          self.meet.racenamecat(self.event),
-                                          'Medal Ceremony',
-                                SCB_RESMEDAL_FMT,
-                                resvec)
+                                              self.event[u'pref'],
+                             self.event[u'info'], SCB_RESMEDAL_FMT, resvec)
         self.meet.scbwin.reset()
         return False
 
@@ -480,33 +467,34 @@ class classification(object):
 
     def editent_cb(self, entry, col):
         """Shared event entry update callback."""
-        if col == eventdb.COL_PREFIX:
-            self.meet.edb.editevent(self.event, prefix=entry.get_text())
-        elif col == eventdb.COL_INFO:
-            self.meet.edb.editevent(self.event, info=entry.get_text())
+        if col == u'pref':
+            self.event[u'pref'] = entry.get_text().decode('utf-8', 'replace')
+        elif col == u'info':
+            self.event[u'info'] = entry.get_text().decode('utf-8', 'replace')
         self.update_expander_lbl_cb()
 
     def editcol_db(self, cell, path, new_text, col):
         """Cell update with writeback to meet."""
-        new_text = new_text.strip()
-        self.riders[path][col] = new_text.strip()
-        glib.idle_add(self.meet.rider_edit, self.riders[path][COL_BIB],
+        new_text = new_text.decode('utf-8','replace').strip()
+        self.riders[path][col] = new_text
+        glib.idle_add(self.meet.rider_edit,
+                      self.riders[path][COL_BIB].decode('utf-8','replace'),
                                            self.series, col, new_text)
 
     def __init__(self, meet, event, ui=True):
         """Constructor."""
         self.meet = meet
         self.event = event      # Note: now a treerowref
-        self.evno = meet.edb.getvalue(event, eventdb.COL_EVNO)
-        self.evtype = meet.edb.getvalue(event, eventdb.COL_TYPE)
-        self.series = meet.edb.getvalue(event, eventdb.COL_SERIES)
+        self.evno = event[u'evid']
+        self.evtype = event[u'type']
+        self.series = event[u'seri']
         self.configpath = meet.event_configfile(self.evno)
         self.log = logging.getLogger('classification')
         self.log.setLevel(logging.DEBUG)
-        self.log.debug('opening event: ' + str(self.evno))
+        self.log.debug(u'opening event: ' + str(self.evno))
 
         # race run time attributes
-        self.onestart = False
+        self.onestart = True	# hack for AJTC
         self.readonly = not ui
         self.winopen = ui
         self.placesrc = ''
@@ -531,15 +519,11 @@ class classification(object):
         b.get_object('omnium_info_evno').set_text(self.evno)
         self.showev = b.get_object('omnium_info_evno_show')
         self.prefix_ent = b.get_object('omnium_info_prefix')
-        self.prefix_ent.set_text(self.meet.edb.getvalue(
-                   self.event, eventdb.COL_PREFIX))
-        self.prefix_ent.connect('changed', self.editent_cb,
-                                 eventdb.COL_PREFIX)
+        self.prefix_ent.set_text(self.event[u'pref'])
+        self.prefix_ent.connect('changed', self.editent_cb,u'pref')
         self.info_ent = b.get_object('omnium_info_title')
-        self.info_ent.set_text(self.meet.edb.getvalue(
-                   self.event, eventdb.COL_INFO))
-        self.info_ent.connect('changed', self.editent_cb,
-                               eventdb.COL_INFO)
+        self.info_ent.set_text(self.event[u'info'])
+        self.info_ent.connect('changed', self.editent_cb,u'info')
         self.update_expander_lbl_cb()
 
         # riders pane
