@@ -805,6 +805,7 @@ class flap(object):
             self.meet.gemini.show_brt()
         # call for a delayed announce...
         glib.idle_add(self.delayed_announce)
+        self.meet.delayed_export()
 
     def timercb(self, e):
         """Handle a timer event."""
@@ -966,7 +967,6 @@ class flap(object):
         # if reqd, do places
         if doplaces:
             self.placexfer()
-            self.meet.delayed_export()
 
     def armstart(self):
         """Arm timer for start trigger."""
@@ -1256,9 +1256,9 @@ class flap(object):
         """Constructor."""
         self.meet = meet
         self.event = event      # Note: now a treerowref
-        self.evno = meet.edb.getvalue(event, eventdb.COL_EVNO)
-        self.evtype = meet.edb.getvalue(event, eventdb.COL_TYPE)
-        self.series = meet.edb.getvalue(event, eventdb.COL_SERIES)
+        self.evno = event[u'evid']
+        self.evtype = event[u'type']
+        self.series = event[u'seri']
         self.configpath = meet.event_configfile(self.evno)
 
         self.log = logging.getLogger('flap')
