@@ -364,8 +364,9 @@ class irtt(object):
                                         u'categories':[],
                                         u'lstart':u'0',
                                         u'startgap':u'1:00',
-                                        u'remote_host':u'',
-                                        u'remote_channel':u'',
+                                        u'remote_host':None,
+                                        u'remote_user':None,
+                                        u'remote_channel':None,
                                         u'intermeds':[],
                                         u'contests':[],
                                         u'tallys':[],
@@ -564,6 +565,7 @@ class irtt(object):
         self.remport = cr.get(u'event', u'remote_host')
         if self.remport and not self.readonly:
             self.remchan = cr.get(u'event', u'remote_channel')
+            self.remote_user = cr.get(u'event', u'remote_user')
             self.remote_timy = uscbsrv.uscbsrv()
             self.remote_timy.start()
             self.log.debug(u'Starting uscbsrv remote timy at: '
@@ -1640,9 +1642,10 @@ class irtt(object):
                 rvec.append(cat)
         return rvec
 
-    def remote_timy_cb(self, msg=None):
+    def remote_timy_cb(self, msg=None, nick=None):
         """Handle a remote timer message."""
-        if msg is not None:
+        if msg is not None and (self.remote_user is None 
+                          or nick.lower()==self.remote_user.lower()):
             if msg.header == 'starter':
                 svec = msg.text.split(chr(unt4.US))
                 if len(svec) > 4:	# assume we are good:
@@ -1687,6 +1690,7 @@ class irtt(object):
 
         # properties
         self.remote_timy = None
+        self.remote_user = None
         self.remport = u''
         self.remchan = u''
 
