@@ -150,10 +150,14 @@ class irtt_start(object):
 
         # countdown txt
         if self.countdown is not None:
+            ctx = u''
+            if self.countdown >= 0:
+                ctx = unicode(self.countdown)
+            else:
+                ctx = u'+' + unicode(-self.countdown)
             oh = 0.09 * self.height
             ch = 0.48 * self.height
-            text_cent(cr, pr, oh, 0.5 * self.width,
-                      str(self.countdown), ch, COUNTERFONT)
+            text_cent(cr, pr, oh, 0.5 * self.width, ctx, ch, COUNTERFONT)
 
         # rider name txt
         if self.riderstr is not None:
@@ -401,7 +405,11 @@ class irtt_start(object):
                 if self.bulb == 'red':
                     self.countdown = cdn
             else:
-                self.countdown = None
+                if cdn < 0 and cdn > -5:
+                    self.countdown = cdn
+                else:
+                    self.countdown = None
+            #self.log.debug(u'Countdown: ' + repr(self.countdown))
         else:
             self.riderstr = u'[finished]'
             # no more riders or error in init.
