@@ -239,6 +239,32 @@ class riderdb(object):
                                            self.model.get_path(iter))
         return ref
 
+    def mkridermap(self, series=u''):
+        """Return a formatted rider map for mkresult scripts."""
+        # Note: Hack until riderdb modified to be same as eventdb
+        ret = {}
+        for r in self.model:
+            if r[COL_SERIES] == series:
+                key = r[COL_BIB].decode('utf-8')
+                first = r[COL_FIRST].decode('utf-8')
+                last = r[COL_LAST].decode('utf-8')
+                club = r[COL_CLUB].decode('utf-8')
+                cat = r[COL_CAT].decode('utf-8')
+                refid = r[COL_REFID].decode('utf-8')
+                ucicode = r[COL_UCICODE].decode('utf-8')
+                rmap = {}
+                rmap[u'bib']=key
+                rmap[u'first']=first
+                rmap[u'last']=last
+                rmap[u'club']=club
+                rmap[u'cat']=cat
+                rmap[u'refid']=refid
+                rmap[u'ucicode']=ucicode
+                rmap[u'namestr']=strops.resname(first, last, club)
+                rmap[u'name']=strops.resname(first, last)
+                ret[key]=rmap
+        return ret
+        
     def mkview(self, bib=True, first=True, last=True, club=True,
                      cat=False, series=True, refid=False, ucicode=False):
         """Create and return view object for the model."""
