@@ -376,6 +376,9 @@ class rr_announce(object):
         return True
 
     def clear(self):
+        self.laptype = None
+        self.lapstart = None
+        self.lapfin = None
         self.lbl_header.set_text(self.motd)
         self.final = False
         self.elap_lbl.set_text('')
@@ -405,7 +408,8 @@ class rr_announce(object):
                         self.cur_lap = self.cur_split.truncate(0)
                     if self.final:
                         # overwrite cur split for down times
-                        self.cur_split = tod.ZERO
+                        self.cur_split = rftime	# check if down from here?
+                        self.cur_lap = rftime
                     self.cur_bunchid = 0
                     self.cur_bunchcnt = 1
                     self.last_time = rftime
@@ -462,6 +466,8 @@ class rr_announce(object):
             self.lapstart = tod.str2tod(m.text)
         elif m.header == 'lapfin':
             self.lapfin = tod.str2tod(m.text)
+        elif m.header == 'resultmsg':
+            self.lbl_resultmsg.set_text(m.text)
         elif m.header == u'laplbl':
             if m.text:
                 self.laplbl = m.text
@@ -658,6 +664,9 @@ class rr_announce(object):
         self.lbl_header = b.get_object('lbl_header')
         self.lbl_header.modify_font(pango.FontDescription(FONTFACE + ' ' + fnszstr))
         self.lbl_header.set_text('metarace road announce ' + metarace.VERSION)
+        self.lbl_resultmsg = b.get_object('lbl_resultmsg')
+        self.lbl_resultmsg.modify_font(pango.FontDescription(FONTFACE + ' ' + fnszstr))
+        self.lbl_resultmsg.set_text(u'')
         self.elap_lbl = b.get_object('elap_lbl')
         self.elap_lbl.set_text('-h--:--')
         self.elap_lbl.modify_font(pango.FontDescription(FONTFACE + ' '+fnszstr))
