@@ -341,7 +341,7 @@ class sportif(object):
             st = self.start
 
         sec = printing.section()
-        sec.heading = u'Individuals'
+        sec.heading = u'Result'
 
         self.reorder_byname()
 
@@ -380,7 +380,7 @@ class sportif(object):
         ret.append(sec)
 
         sec = printing.section()
-        sec.heading = u'Teams'
+        sec.heading = u'Teams Result'
         tres = []
         for team in tmap:
             rvec = tmap[team]
