@@ -239,7 +239,7 @@ def resname_bib(bib, first, last, club):
         ret += u' (' + club + u')'
     return ret
 
-def resname(first, last, club):
+def resname(first, last=None, club=None):
     """Return rider name formatted for results."""
     ret = fitname(first, last, 64)
     if club is not None and club != u'':
