@@ -838,16 +838,16 @@ if __name__ == "__main__":
         #t.setport(u'192.168.95.252')
         t.setport(u'/dev/ttyUSB0')
         t.sane()
-        t.setlvl(u'00', u'00')
-        #t.set_date()
-        #t.sync()
+        t.setlvl(u'00', u'90')
+        t.set_date()
+        t.sync()
         t.setcb(printtag)
         #t.stop_session()
         #glib.timeout_add_seconds(5, doconfig, t)
         #glib.timeout_add_seconds(4, dostop, t)
         #glib.timeout_add_seconds(6, doconfig, t)
         #glib.timeout_add_seconds(15, dostart, t)
-        #t.start_session()
+        t.start_session()
         gtk.main()
     except:
         t.stop_session()
